Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc

Issue 1846653004: Rename IGNORING_CACHE to BYPASSING_CACHE (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/app_mode/app_mode_utils.cc ('k') | chrome/browser/extensions/api/tabs/tabs_api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc
diff --git a/chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc b/chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc
index 5fa079792eaa65b365c26a60170319a7bfbf5b06..d073a91de0046fcb6e8064b3404e274475910acc 100644
--- a/chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc
+++ b/chrome/browser/chromeos/login/ui/simple_web_view_dialog.cc
@@ -137,7 +137,7 @@ SimpleWebViewDialog::SimpleWebViewDialog(Profile* profile)
command_updater_->UpdateCommandEnabled(IDC_FORWARD, true);
command_updater_->UpdateCommandEnabled(IDC_STOP, true);
command_updater_->UpdateCommandEnabled(IDC_RELOAD, true);
- command_updater_->UpdateCommandEnabled(IDC_RELOAD_IGNORING_CACHE, true);
+ command_updater_->UpdateCommandEnabled(IDC_RELOAD_BYPASSING_CACHE, true);
command_updater_->UpdateCommandEnabled(IDC_RELOAD_CLEARING_CACHE, true);
}
@@ -349,11 +349,11 @@ void SimpleWebViewDialog::ExecuteCommandWithDisposition(
web_contents->Stop();
break;
case IDC_RELOAD:
- // Always reload ignoring cache.
- case IDC_RELOAD_IGNORING_CACHE:
+ // Always reload bypassing cache.
+ case IDC_RELOAD_BYPASSING_CACHE:
case IDC_RELOAD_CLEARING_CACHE:
location_bar_->Revert();
- web_contents->GetController().ReloadIgnoringCache(true);
+ web_contents->GetController().ReloadBypassingCache(true);
break;
default:
NOTREACHED();
« no previous file with comments | « chrome/browser/app_mode/app_mode_utils.cc ('k') | chrome/browser/extensions/api/tabs/tabs_api.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698